# Angle Based Dictionary Learning for Outlier Detection

## Description
This script benchmarks a variety of outlier detection algorithms using the PyOD library, with a specific focus on the "Angle-based Dictionary Learning for Outlier Detection" methods. The main objective is to compare the performance of different algorithms based on several datasets and record their ROC, Precision @ rank n, and execution time.

## Dependencies

- Python 3+
- Numpy
- Pandas
- Scikit-learn
- scipy
- [pyod](https://github.com/yzhao062/pyod) (Python Outlier Detection)

## Main Features

- Multiple outlier detection algorithms are tested, including common ones from the PyOD library as well as newly implemented angle-based dictionary learning methods.
- Results, including ROC, precision @ rank n, and execution time, are recorded for each algorithm and each dataset.
- Results are stored in CSV files for further analysis.

## How to Run

1. Ensure you have all the necessary dependencies installed. Copy the provided models in the pyod (models) folder.
2. Place your datasets in a directory named `data`.
3. Run the script using your preferred Python environment or IDE.
4. Once completed, inspect the `.csv` files generated in the root directory for the results.

	```python3 benchmark_abdl.py```

## Datasets
The script expects the following datasets in MATLAB format:

- arrhythmia.mat
- cardio.mat
- glass.mat
- ionosphere.mat
- letter.mat
- lympho.mat
- mnist.mat
- musk.mat
- optdigits.mat
- pendigits.mat
- pima.mat
- satellite.mat
- satimage-2.mat
- shuttle.mat
- vertebral.mat
- vowels.mat
- wbc.mat

## Citing Us

This represents the main resources necessary for reproducing the results presented in “Angle-based Dictionary Learning for Outlier Detection”, by Denis C. Ilie Ablachim and Bogdan Dumitrescu. If you use our work please cite the following paper

```
@inproceedings{abdl2023,
  title={Angle-based Dictionary Learning for Outlier Detection},
  author={Ilie-Ablachim, Denis C and Dumitrescu, Bogdan},
  booktitle={3rd IEEE International Conference on Signal, Control and Communication (SCC 2023) - submitted},
  year={2023},
  organization={IEEE}
}
```

## Funding

This work is supported by a grant of the Ministry of Research, Innovation and Digitization, CNCS – UEFISCDI, project number PN-III-P4-PCE-2021-0154, within PNCDI III.

This `README.md` provides an overview of the script, its dependencies, how to use it, and what results to expect. Adjustments might be required to better fit the exact needs or specifications of the project.